aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/phpbb/di/extension/core.php
diff options
context:
space:
mode:
Diffstat (limited to 'phpBB/phpbb/di/extension/core.php')
-rw-r--r--phpBB/phpbb/di/extension/core.php12
1 files changed, 6 insertions, 6 deletions
diff --git a/phpBB/phpbb/di/extension/core.php b/phpBB/phpbb/di/extension/core.php
index 9c36ba2fc4..9d59a24b7e 100644
--- a/phpBB/phpbb/di/extension/core.php
+++ b/phpBB/phpbb/di/extension/core.php
@@ -26,19 +26,19 @@ use Symfony\Component\Config\FileLocator;
class phpbb_di_extension_core extends Extension
{
/**
- * phpBB Root path
+ * Config path
* @var string
*/
- protected $root_path;
+ protected $config_path;
/**
* Constructor
*
* @param string $root_path Root path
*/
- public function __construct($root_path)
+ public function __construct($config_path)
{
- $this->root_path = $root_path;
+ $this->config_path = $config_path;
}
/**
@@ -51,7 +51,7 @@ class phpbb_di_extension_core extends Extension
*/
public function load(array $config, ContainerBuilder $container)
{
- $loader = new YamlFileLoader($container, new FileLocator(phpbb_realpath($this->root_path . 'config')));
+ $loader = new YamlFileLoader($container, new FileLocator(phpbb_realpath($this->config_path)));
$loader->load('services.yml');
}
@@ -26,19 +26,19 @@ use Symfony\Component\Config\FileLocator;
* Constructor
*
- * @param string $root_path Root path
+ * @param string $config_path Config path
*/